#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, Rect, Path, EmptyClipPath
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=400,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(Rect(0,0,5,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(5,0,5,100,rx=0,ry=0,fillColor=Color(.947368,0,.052632,1),fillOpacity=None,strokeColor=Color(.947368,0,.052632,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(10,0,5,100,rx=0,ry=0,fillColor=Color(.894737,0,.105263,1),fillOpacity=None,strokeColor=Color(.894737,0,.105263,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(15,0,5,100,rx=0,ry=0,fillColor=Color(.842105,0,.157895,1),fillOpacity=None,strokeColor=Color(.842105,0,.157895,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(20,0,5,100,rx=0,ry=0,fillColor=Color(.789474,0,.210526,1),fillOpacity=None,strokeColor=Color(.789474,0,.210526,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(25,0,5,100,rx=0,ry=0,fillColor=Color(.736842,0,.263158,1),fillOpacity=None,strokeColor=Color(.736842,0,.263158,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(30,0,5,100,rx=0,ry=0,fillColor=Color(.684211,0,.315789,1),fillOpacity=None,strokeColor=Color(.684211,0,.315789,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(35,0,5,100,rx=0,ry=0,fillColor=Color(.631579,0,.368421,1),fillOpacity=None,strokeColor=Color(.631579,0,.368421,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(40,0,5,100,rx=0,ry=0,fillColor=Color(.578947,0,.421053,1),fillOpacity=None,strokeColor=Color(.578947,0,.421053,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(45,0,5,100,rx=0,ry=0,fillColor=Color(.526316,0,.473684,1),fillOpacity=None,strokeColor=Color(.526316,0,.473684,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(50,0,5,100,rx=0,ry=0,fillColor=Color(.473684,0,.526316,1),fillOpacity=None,strokeColor=Color(.473684,0,.526316,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(55,0,5,100,rx=0,ry=0,fillColor=Color(.421053,0,.578947,1),fillOpacity=None,strokeColor=Color(.421053,0,.578947,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(60,0,5,100,rx=0,ry=0,fillColor=Color(.368421,0,.631579,1),fillOpacity=None,strokeColor=Color(.368421,0,.631579,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(65,0,5,100,rx=0,ry=0,fillColor=Color(.315789,0,.684211,1),fillOpacity=None,strokeColor=Color(.315789,0,.684211,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(70,0,5,100,rx=0,ry=0,fillColor=Color(.263158,0,.736842,1),fillOpacity=None,strokeColor=Color(.263158,0,.736842,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(75,0,5,100,rx=0,ry=0,fillColor=Color(.210526,0,.789474,1),fillOpacity=None,strokeColor=Color(.210526,0,.789474,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(80,0,5,100,rx=0,ry=0,fillColor=Color(.157895,0,.842105,1),fillOpacity=None,strokeColor=Color(.157895,0,.842105,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(85,0,5,100,rx=0,ry=0,fillColor=Color(.105263,0,.894737,1),fillOpacity=None,strokeColor=Color(.105263,0,.894737,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(90,0,5,100,rx=0,ry=0,fillColor=Color(.052632,0,.947368,1),fillOpacity=None,strokeColor=Color(.052632,0,.947368,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(95,0,5,100,rx=0,ry=0,fillColor=Color(0,0,1,1),fillOpacity=None,strokeColor=Color(0,0,1,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(0,0,100,100,rx=0,ry=0,fillColor=None,fillOpacity=None,strokeColor=Color(1,1,0,1),strokeWidth=2,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Path(points=[110,110,160,180,210,110],operators=[0,1,1,3],isClipPath=1,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (0,-1,1,0,-133.3333,160)
		v0.add(Rect(-20,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(1,0,0,1),fillOpacity=None,strokeColor=Color(1,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-18.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.979592,.010244,0,1),fillOpacity=None,strokeColor=Color(.979592,.010244,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-17.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.959184,.020488,0,1),fillOpacity=None,strokeColor=Color(.959184,.020488,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-15.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.938776,.030732,0,1),fillOpacity=None,strokeColor=Color(.938776,.030732,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-14.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.918367,.040976,0,1),fillOpacity=None,strokeColor=Color(.918367,.040976,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-13,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.897959,.05122,0,1),fillOpacity=None,strokeColor=Color(.897959,.05122,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-11.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.877551,.061465,0,1),fillOpacity=None,strokeColor=Color(.877551,.061465,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-10.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.857143,.071709,0,1),fillOpacity=None,strokeColor=Color(.857143,.071709,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-8.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.836735,.081953,0,1),fillOpacity=None,strokeColor=Color(.836735,.081953,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-7.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.816327,.092197,0,1),fillOpacity=None,strokeColor=Color(.816327,.092197,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.795918,.102441,0,1),fillOpacity=None,strokeColor=Color(.795918,.102441,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-4.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.77551,.112685,0,1),fillOpacity=None,strokeColor=Color(.77551,.112685,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-3.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.755102,.122929,0,1),fillOpacity=None,strokeColor=Color(.755102,.122929,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-1.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.734694,.133173,0,1),fillOpacity=None,strokeColor=Color(.734694,.133173,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(-0.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.714286,.143417,0,1),fillOpacity=None,strokeColor=Color(.714286,.143417,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(1,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.693878,.153661,0,1),fillOpacity=None,strokeColor=Color(.693878,.153661,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(2.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.673469,.163906,0,1),fillOpacity=None,strokeColor=Color(.673469,.163906,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(3.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.653061,.17415,0,1),fillOpacity=None,strokeColor=Color(.653061,.17415,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(5.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.632653,.184394,0,1),fillOpacity=None,strokeColor=Color(.632653,.184394,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(6.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.612245,.194638,0,1),fillOpacity=None,strokeColor=Color(.612245,.194638,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.591837,.204882,0,1),fillOpacity=None,strokeColor=Color(.591837,.204882,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(9.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.571429,.215126,0,1),fillOpacity=None,strokeColor=Color(.571429,.215126,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(10.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.55102,.22537,0,1),fillOpacity=None,strokeColor=Color(.55102,.22537,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(12.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.530612,.235614,0,1),fillOpacity=None,strokeColor=Color(.530612,.235614,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(13.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.510204,.245858,0,1),fillOpacity=None,strokeColor=Color(.510204,.245858,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(15,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.489796,.256102,0,1),fillOpacity=None,strokeColor=Color(.489796,.256102,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(16.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.469388,.266347,0,1),fillOpacity=None,strokeColor=Color(.469388,.266347,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(17.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.44898,.276591,0,1),fillOpacity=None,strokeColor=Color(.44898,.276591,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(19.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.428571,.286835,0,1),fillOpacity=None,strokeColor=Color(.428571,.286835,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(20.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.408163,.297079,0,1),fillOpacity=None,strokeColor=Color(.408163,.297079,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(22,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.387755,.307323,0,1),fillOpacity=None,strokeColor=Color(.387755,.307323,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(23.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.367347,.317567,0,1),fillOpacity=None,strokeColor=Color(.367347,.317567,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(24.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.346939,.327811,0,1),fillOpacity=None,strokeColor=Color(.346939,.327811,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(26.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.326531,.338055,0,1),fillOpacity=None,strokeColor=Color(.326531,.338055,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(27.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.306122,.348299,0,1),fillOpacity=None,strokeColor=Color(.306122,.348299,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(29,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.285714,.358543,0,1),fillOpacity=None,strokeColor=Color(.285714,.358543,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(30.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.265306,.368788,0,1),fillOpacity=None,strokeColor=Color(.265306,.368788,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(31.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.244898,.379032,0,1),fillOpacity=None,strokeColor=Color(.244898,.379032,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(33.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.22449,.389276,0,1),fillOpacity=None,strokeColor=Color(.22449,.389276,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(34.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.204082,.39952,0,1),fillOpacity=None,strokeColor=Color(.204082,.39952,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(36,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.183673,.409764,0,1),fillOpacity=None,strokeColor=Color(.183673,.409764,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(37.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.163265,.420008,0,1),fillOpacity=None,strokeColor=Color(.163265,.420008,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(38.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.142857,.430252,0,1),fillOpacity=None,strokeColor=Color(.142857,.430252,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(40.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.122449,.440496,0,1),fillOpacity=None,strokeColor=Color(.122449,.440496,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(41.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.102041,.45074,0,1),fillOpacity=None,strokeColor=Color(.102041,.45074,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(43,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.081633,.460984,0,1),fillOpacity=None,strokeColor=Color(.081633,.460984,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(44.4,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.061224,.471228,0,1),fillOpacity=None,strokeColor=Color(.061224,.471228,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(45.8,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.040816,.481473,0,1),fillOpacity=None,strokeColor=Color(.040816,.481473,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(47.2,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(.020408,.491717,0,1),fillOpacity=None,strokeColor=Color(.020408,.491717,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(48.6,243.3333,1.4,100,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(EmptyClipPath)
		self.add(Path(points=[110,110,160,180,210,110],operators=[0,1,1,3],isClipPath=0,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(220,10,2.380952,180,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(222.381,10,2.380952,180,rx=0,ry=0,fillColor=Color(.090909,.547237,0,1),fillOpacity=None,strokeColor=Color(.090909,.547237,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(224.7619,10,2.380952,180,rx=0,ry=0,fillColor=Color(.181818,.592513,0,1),fillOpacity=None,strokeColor=Color(.181818,.592513,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(227.1429,10,2.380952,180,rx=0,ry=0,fillColor=Color(.272727,.63779,0,1),fillOpacity=None,strokeColor=Color(.272727,.63779,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(229.5238,10,2.380952,180,rx=0,ry=0,fillColor=Color(.363636,.683066,0,1),fillOpacity=None,strokeColor=Color(.363636,.683066,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(231.9048,10,2.380952,180,rx=0,ry=0,fillColor=Color(.454545,.728342,0,1),fillOpacity=None,strokeColor=Color(.454545,.728342,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(234.2857,10,2.380952,180,rx=0,ry=0,fillColor=Color(.545455,.773619,0,1),fillOpacity=None,strokeColor=Color(.545455,.773619,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(236.6667,10,2.380952,180,rx=0,ry=0,fillColor=Color(.636364,.818895,0,1),fillOpacity=None,strokeColor=Color(.636364,.818895,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(239.0476,10,2.380952,180,rx=0,ry=0,fillColor=Color(.727273,.864171,0,1),fillOpacity=None,strokeColor=Color(.727273,.864171,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(241.4286,10,2.380952,180,rx=0,ry=0,fillColor=Color(.818182,.909447,0,1),fillOpacity=None,strokeColor=Color(.818182,.909447,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(243.8095,10,2.380952,180,rx=0,ry=0,fillColor=Color(.909091,.954724,0,1),fillOpacity=None,strokeColor=Color(.909091,.954724,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(246.1905,10,2.380952,180,rx=0,ry=0,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(1,1,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(248.5714,10,2.380952,180,rx=0,ry=0,fillColor=Color(.888889,.944662,0,1),fillOpacity=None,strokeColor=Color(.888889,.944662,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(250.9524,10,2.380952,180,rx=0,ry=0,fillColor=Color(.777778,.889325,0,1),fillOpacity=None,strokeColor=Color(.777778,.889325,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(253.3333,10,2.380952,180,rx=0,ry=0,fillColor=Color(.666667,.833987,0,1),fillOpacity=None,strokeColor=Color(.666667,.833987,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(255.7143,10,2.380952,180,rx=0,ry=0,fillColor=Color(.555556,.778649,0,1),fillOpacity=None,strokeColor=Color(.555556,.778649,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(258.0952,10,2.380952,180,rx=0,ry=0,fillColor=Color(.444444,.723312,0,1),fillOpacity=None,strokeColor=Color(.444444,.723312,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(260.4762,10,2.380952,180,rx=0,ry=0,fillColor=Color(.333333,.667974,0,1),fillOpacity=None,strokeColor=Color(.333333,.667974,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(262.8571,10,2.380952,180,rx=0,ry=0,fillColor=Color(.222222,.612636,0,1),fillOpacity=None,strokeColor=Color(.222222,.612636,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(265.2381,10,2.380952,180,rx=0,ry=0,fillColor=Color(.111111,.557298,0,1),fillOpacity=None,strokeColor=Color(.111111,.557298,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Rect(267.619,10,2.380952,180,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Path(points=[280,10,280,190,330,190,330,10],operators=[0,1,1,1,3],isClipPath=1,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.984808,-0.173648,.173648,.984808,-317.7312,-45.51808)
		v0.add(Rect(547.753,158.4696,80.49706,3.646035,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,162.1156,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.038462,.521116,0,1),fillOpacity=None,strokeColor=Color(.038462,.521116,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,165.7616,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.076923,.540271,0,1),fillOpacity=None,strokeColor=Color(.076923,.540271,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,169.4077,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.115385,.559427,0,1),fillOpacity=None,strokeColor=Color(.115385,.559427,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,173.0537,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.153846,.578582,0,1),fillOpacity=None,strokeColor=Color(.153846,.578582,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,176.6997,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.192308,.597738,0,1),fillOpacity=None,strokeColor=Color(.192308,.597738,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,180.3458,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.230769,.616893,0,1),fillOpacity=None,strokeColor=Color(.230769,.616893,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,183.9918,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.269231,.636048,0,1),fillOpacity=None,strokeColor=Color(.269231,.636048,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,187.6379,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.307692,.655204,0,1),fillOpacity=None,strokeColor=Color(.307692,.655204,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,191.2839,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.346154,.674359,0,1),fillOpacity=None,strokeColor=Color(.346154,.674359,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,194.9299,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.384615,.693514,0,1),fillOpacity=None,strokeColor=Color(.384615,.693514,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,198.576,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.423077,.71267,0,1),fillOpacity=None,strokeColor=Color(.423077,.71267,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,202.222,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.461538,.731825,0,1),fillOpacity=None,strokeColor=Color(.461538,.731825,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,205.868,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.5,.75098,0,1),fillOpacity=None,strokeColor=Color(.5,.75098,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,209.5141,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.538462,.770136,0,1),fillOpacity=None,strokeColor=Color(.538462,.770136,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,213.1601,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.576923,.789291,0,1),fillOpacity=None,strokeColor=Color(.576923,.789291,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,216.8061,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.615385,.808446,0,1),fillOpacity=None,strokeColor=Color(.615385,.808446,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,220.4522,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.653846,.827602,0,1),fillOpacity=None,strokeColor=Color(.653846,.827602,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,224.0982,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.692308,.846757,0,1),fillOpacity=None,strokeColor=Color(.692308,.846757,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,227.7442,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.730769,.865913,0,1),fillOpacity=None,strokeColor=Color(.730769,.865913,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,231.3903,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.769231,.885068,0,1),fillOpacity=None,strokeColor=Color(.769231,.885068,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,235.0363,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.807692,.904223,0,1),fillOpacity=None,strokeColor=Color(.807692,.904223,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,238.6823,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.846154,.923379,0,1),fillOpacity=None,strokeColor=Color(.846154,.923379,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,242.3284,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.884615,.942534,0,1),fillOpacity=None,strokeColor=Color(.884615,.942534,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,245.9744,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.923077,.961689,0,1),fillOpacity=None,strokeColor=Color(.923077,.961689,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,249.6205,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.961538,.980845,0,1),fillOpacity=None,strokeColor=Color(.961538,.980845,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,253.2665,80.49706,3.646035,rx=0,ry=0,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(1,1,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,256.9125,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.958333,.979248,0,1),fillOpacity=None,strokeColor=Color(.958333,.979248,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,260.5586,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.916667,.958497,0,1),fillOpacity=None,strokeColor=Color(.916667,.958497,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,264.2046,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.875,.937745,0,1),fillOpacity=None,strokeColor=Color(.875,.937745,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,267.8506,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.833333,.916993,0,1),fillOpacity=None,strokeColor=Color(.833333,.916993,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,271.4967,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.791667,.896242,0,1),fillOpacity=None,strokeColor=Color(.791667,.896242,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,275.1427,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.75,.87549,0,1),fillOpacity=None,strokeColor=Color(.75,.87549,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,278.7887,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.708333,.854739,0,1),fillOpacity=None,strokeColor=Color(.708333,.854739,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,282.4348,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.666667,.833987,0,1),fillOpacity=None,strokeColor=Color(.666667,.833987,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,286.0808,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.625,.813235,0,1),fillOpacity=None,strokeColor=Color(.625,.813235,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,289.7268,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.583333,.792484,0,1),fillOpacity=None,strokeColor=Color(.583333,.792484,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,293.3729,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.541667,.771732,0,1),fillOpacity=None,strokeColor=Color(.541667,.771732,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,297.0189,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.5,.75098,0,1),fillOpacity=None,strokeColor=Color(.5,.75098,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,300.6649,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.458333,.730229,0,1),fillOpacity=None,strokeColor=Color(.458333,.730229,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,304.311,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.416667,.709477,0,1),fillOpacity=None,strokeColor=Color(.416667,.709477,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,307.957,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.375,.688725,0,1),fillOpacity=None,strokeColor=Color(.375,.688725,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,311.6031,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.333333,.667974,0,1),fillOpacity=None,strokeColor=Color(.333333,.667974,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,315.2491,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.291667,.647222,0,1),fillOpacity=None,strokeColor=Color(.291667,.647222,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,318.8951,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.25,.626471,0,1),fillOpacity=None,strokeColor=Color(.25,.626471,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,322.5412,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.208333,.605719,0,1),fillOpacity=None,strokeColor=Color(.208333,.605719,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,326.1872,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.166667,.584967,0,1),fillOpacity=None,strokeColor=Color(.166667,.584967,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,329.8332,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.125,.564216,0,1),fillOpacity=None,strokeColor=Color(.125,.564216,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,333.4793,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.083333,.543464,0,1),fillOpacity=None,strokeColor=Color(.083333,.543464,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,337.1253,80.49706,3.646035,rx=0,ry=0,fillColor=Color(.041667,.522712,0,1),fillOpacity=None,strokeColor=Color(.041667,.522712,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(547.753,340.7713,80.49706,3.646035,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(EmptyClipPath)
		self.add(Path(points=[280,10,280,190,330,190,330,10],operators=[0,1,1,1,3],isClipPath=0,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Path(points=[340,10,340,190,390,190,390,10],operators=[0,1,1,1,3],isClipPath=1,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (.707107,-0.707107,.707107,.707107,-328.8047,187.3833)
		v0.add(Rect(471.066,347.4874,162.6346,3.188913,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,350.6763,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.038462,.521116,0,1),fillOpacity=None,strokeColor=Color(.038462,.521116,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,353.8652,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.076923,.540271,0,1),fillOpacity=None,strokeColor=Color(.076923,.540271,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,357.0541,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.115385,.559427,0,1),fillOpacity=None,strokeColor=Color(.115385,.559427,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,360.243,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.153846,.578582,0,1),fillOpacity=None,strokeColor=Color(.153846,.578582,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,363.4319,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.192308,.597738,0,1),fillOpacity=None,strokeColor=Color(.192308,.597738,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,366.6209,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.230769,.616893,0,1),fillOpacity=None,strokeColor=Color(.230769,.616893,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,369.8098,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.269231,.636048,0,1),fillOpacity=None,strokeColor=Color(.269231,.636048,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,372.9987,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.307692,.655204,0,1),fillOpacity=None,strokeColor=Color(.307692,.655204,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,376.1876,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.346154,.674359,0,1),fillOpacity=None,strokeColor=Color(.346154,.674359,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,379.3765,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.384615,.693514,0,1),fillOpacity=None,strokeColor=Color(.384615,.693514,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,382.5654,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.423077,.71267,0,1),fillOpacity=None,strokeColor=Color(.423077,.71267,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,385.7543,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.461538,.731825,0,1),fillOpacity=None,strokeColor=Color(.461538,.731825,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,388.9432,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.5,.75098,0,1),fillOpacity=None,strokeColor=Color(.5,.75098,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,392.1322,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.538462,.770136,0,1),fillOpacity=None,strokeColor=Color(.538462,.770136,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,395.3211,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.576923,.789291,0,1),fillOpacity=None,strokeColor=Color(.576923,.789291,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,398.51,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.615385,.808446,0,1),fillOpacity=None,strokeColor=Color(.615385,.808446,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,401.6989,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.653846,.827602,0,1),fillOpacity=None,strokeColor=Color(.653846,.827602,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,404.8878,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.692308,.846757,0,1),fillOpacity=None,strokeColor=Color(.692308,.846757,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,408.0767,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.730769,.865913,0,1),fillOpacity=None,strokeColor=Color(.730769,.865913,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,411.2656,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.769231,.885068,0,1),fillOpacity=None,strokeColor=Color(.769231,.885068,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,414.4545,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.807692,.904223,0,1),fillOpacity=None,strokeColor=Color(.807692,.904223,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,417.6435,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.846154,.923379,0,1),fillOpacity=None,strokeColor=Color(.846154,.923379,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,420.8324,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.884615,.942534,0,1),fillOpacity=None,strokeColor=Color(.884615,.942534,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,424.0213,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.923077,.961689,0,1),fillOpacity=None,strokeColor=Color(.923077,.961689,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,427.2102,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.961538,.980845,0,1),fillOpacity=None,strokeColor=Color(.961538,.980845,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,430.3991,162.6346,3.188913,rx=0,ry=0,fillColor=Color(1,1,0,1),fillOpacity=None,strokeColor=Color(1,1,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,433.588,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.958333,.979248,0,1),fillOpacity=None,strokeColor=Color(.958333,.979248,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,436.7769,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.916667,.958497,0,1),fillOpacity=None,strokeColor=Color(.916667,.958497,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,439.9658,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.875,.937745,0,1),fillOpacity=None,strokeColor=Color(.875,.937745,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,443.1548,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.833333,.916993,0,1),fillOpacity=None,strokeColor=Color(.833333,.916993,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,446.3437,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.791667,.896242,0,1),fillOpacity=None,strokeColor=Color(.791667,.896242,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,449.5326,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.75,.87549,0,1),fillOpacity=None,strokeColor=Color(.75,.87549,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,452.7215,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.708333,.854739,0,1),fillOpacity=None,strokeColor=Color(.708333,.854739,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,455.9104,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.666667,.833987,0,1),fillOpacity=None,strokeColor=Color(.666667,.833987,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,459.0993,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.625,.813235,0,1),fillOpacity=None,strokeColor=Color(.625,.813235,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,462.2882,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.583333,.792484,0,1),fillOpacity=None,strokeColor=Color(.583333,.792484,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,465.4772,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.541667,.771732,0,1),fillOpacity=None,strokeColor=Color(.541667,.771732,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,468.6661,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.5,.75098,0,1),fillOpacity=None,strokeColor=Color(.5,.75098,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,471.855,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.458333,.730229,0,1),fillOpacity=None,strokeColor=Color(.458333,.730229,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,475.0439,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.416667,.709477,0,1),fillOpacity=None,strokeColor=Color(.416667,.709477,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,478.2328,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.375,.688725,0,1),fillOpacity=None,strokeColor=Color(.375,.688725,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,481.4217,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.333333,.667974,0,1),fillOpacity=None,strokeColor=Color(.333333,.667974,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,484.6106,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.291667,.647222,0,1),fillOpacity=None,strokeColor=Color(.291667,.647222,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,487.7995,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.25,.626471,0,1),fillOpacity=None,strokeColor=Color(.25,.626471,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,490.9885,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.208333,.605719,0,1),fillOpacity=None,strokeColor=Color(.208333,.605719,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,494.1774,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.166667,.584967,0,1),fillOpacity=None,strokeColor=Color(.166667,.584967,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,497.3663,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.125,.564216,0,1),fillOpacity=None,strokeColor=Color(.125,.564216,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,500.5552,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.083333,.543464,0,1),fillOpacity=None,strokeColor=Color(.083333,.543464,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,503.7441,162.6346,3.188913,rx=0,ry=0,fillColor=Color(.041667,.522712,0,1),fillOpacity=None,strokeColor=Color(.041667,.522712,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0.add(Rect(471.066,506.933,162.6346,3.188913,rx=0,ry=0,fillColor=Color(0,.501961,0,1),fillOpacity=None,strokeColor=Color(0,.501961,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(EmptyClipPath)
		self.add(Path(points=[340,10,340,190,390,190,390,10],operators=[0,1,1,1,3],isClipPath=0,autoclose=None,fillMode=0,fillColor=None,fillOpacity=None,strokeColor=None,strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)



#Autogenerated by ReportLab guiedit do not edit
from reportlab.graphics.shapes import _DrawingEditorMixin, Drawing, Group, PolyLine, Line, String
from reportlab.lib.colors import Color, CMYKColor, PCMYKColor

class ExplodedDrawing_Drawing(_DrawingEditorMixin,Drawing):
	def __init__(self,width=200,height=200,*args,**kw):
		Drawing.__init__(self,width,height,*args,**kw)
		self.transform = (1,0,0,1,0,0)
		self.add(PolyLine(points=[41.54329,133.75,100,156.25,158.4567,133.75,168.1995,60.625,100,10,31.8005,60.625,41.54329,133.75],strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(PolyLine(points=[46.41468,130.9375,100,133.75,138.9711,122.5,148.7139,71.875,100,32.5,56.15746,74.6875,46.41468,130.9375],strokeColor=Color(0,0,0,1),strokeWidth=1,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		self.add(Line(100,100,100,190,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,100,194.5)
		v0.add(String(-2.22,-4,'a',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(100,100,177.9423,145,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,181.8394,147.25)
		v0.add(String(-2.5,-4,'b',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(100,100,177.9423,55,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,181.8394,52.75)
		v0.add(String(-2.22,-4,'c',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(100,100,100,10,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,100,5.5)
		v0.add(String(-2.5,-4,'d',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(100,100,22.05771,55,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,18.1606,52.75)
		v0.add(String(-2.22,-4,'e',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))
		self.add(Line(100,100,22.05771,145,strokeColor=Color(0,0,0,1),strokeWidth=.5,strokeLineCap=0,strokeLineJoin=0,strokeMiterLimit=0,strokeDashArray=None,strokeOpacity=None))
		v0=self._nn(Group())
		v0.transform = (1,0,0,1,18.1606,147.25)
		v0.add(String(-1.665,-4,'f',textAnchor='start',fontName='Times-Roman',fontSize=10,fillColor=Color(0,0,0,1)))


if __name__=="__main__": #NORUNTESTS
	ExplodedDrawing_Drawing().save(formats=['pdf'],outDir='.',fnRoot=None)
